/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Pierre-Alain Loizeau [committer], Felix Weiglhofer, Dominik Smith */
#include "Exceptions.h"
#include "ReadoutPars.h"

using namespace cbm::algo::bmon::config;

ReadoutPars ReadoutPars::MakeMCBM2024()
{
  // This here refers to the mCBM 2024 setups.
  // Taken from CbmMcbm2018TofPar in combination with macro/beamtime/mcbm2024/mBmonCriPar

  ReadoutPars pars;

  pars.nFebsPerComponent = 10;
  pars.nAsicsPerFeb      = 8;
  pars.nChannelsPerAsic  = 4;
  pars.nCrobPerComponent = 2;

  constexpr int NumCrob = 10;

  // Module Identifier connected to Gbtx link, has to match geometry
  const int32_t moduleId[NumCrob] = {0, -1, 0, -1, 0, -1, 0, -1, 0, -1};

  // type of Rpcs connected to Gbtx link
  const int32_t rpcType[NumCrob] = {99, -1, 99, -1, 99, -1, 99, -1, 99, -1};

  // side of Rpcs connected to Gbtx link, i.e. 0 or 1
  const int32_t rpcSide[NumCrob] = {0, 0, 0, 0, 0, 0, 0, 0, 1, 0};

  // number of Rpcs connected to Gbtx link, i.e. 3 or 5
  const int32_t numRpc[NumCrob] = {1, 0, 1, 0, 1, 0, 1, 0, 1, 0};

  for (int i = 0; i < NumCrob; ++i) {
    pars.crobs.push_back({moduleId[i], rpcType[i], rpcSide[i], numRpc[i]});
  }

  pars.eqIds = {0xabf3, 0xabf2, 0xabf1, 0xabf0, 0xabf4};

  return pars;
}
